#
# spec file for package perl-ExtUtils-F77
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name ExtUtils-F77
Name:           perl-ExtUtils-F77
Version:        1.26
Release:        1.14
Summary:        Simple interface to F77 libs
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETJ/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(File::Which)
Requires:       perl(File::Which)
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  gcc-fortran
BuildRequires:  gmp-devel
# MANUAL END

%description
This module tries to figure out how to link C programs with Fortran
subroutines on your system. Basically one must add a list of Fortran
runtime libraries. The problem is their location and name varies with each
OS/compiler combination! It was originally developed to make building and
installation of the PGPLOT module easier, which links to the pgplot Fortran
graphics library. It is now used by a number of perl modules.

This module tries to implement a simple 'rule-of-thumb' database for
various flavours of UNIX systems. A simple self-documenting Perl database
of knowledge/code for figuring out how to link for various combinations of
OS and compiler is embedded in the modules Perl code. Please help save the
world by submitted patches for new database entries for your system at
https://github.com/PDLPorters/extutils-f77

Note the default on most systems is now to search for a generic 'GNU'
compiler which can be gfortran, g77, g95 or fort77 (in that order based on
usage) and then find the appropriate link libraries automatically. (This is
the 'Generic' 'GNU' database entry in the code.)

The target compiler can be explicitly overriden by setting the environment
variable F77, e.g.

 % setenv F77 "x86_64-pc-linux-gnu-gfortran"
 % perl -MExtUtils::F77 -e 'print ExtUtils::F77->compiler, "\n"'

The library list which the module returns can be explicitly overridden by
setting the environment variable F77LIBS, e.g.

  % setenv F77LIBS "-lfoo -lbar"
  % perl -MExtUtils::F77 -e 'print ExtUtils::F77->runtime, "\n"'
  ...

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc CHANGES README
%license COPYING

%changelog
* Tue Feb 16 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.26
  see /usr/share/doc/packages/perl-ExtUtils-F77/CHANGES
* Sun Jul 21 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.24
  see /usr/share/doc/packages/perl-ExtUtils-F77/CHANGES
  v1.24 released Jul 21st 2019
  - --------------------------
  * Fix of library order of -lgfortran and -lquadmath which effected MS Windows
* Sun Jan  6 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.23
  see /usr/share/doc/packages/perl-ExtUtils-F77/CHANGES
  v1.23 released Jan 5th 2019
  - --------------------------
  * Use File::Which and List::Util instead of bespoke code (mohawk2)
  * Improvements to docs (karlglazebrook,mohawk2)
  * improvements to tests and warnings (mohawk2)
  * tidy up of code (mohawk2)
  * simplify out of gfortran handling (mohawk2)
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.22
  see /usr/share/doc/packages/perl-ExtUtils-F77/CHANGES
  v1.22 released Dec 2nd 2018
  - --------------------------
  * Fixed some minor typos in README and F77.pm
  v1.21 released Nov 25th 2018
  - ----------------------------
  * Adjust ordering of searched for Generic GNU compilers (Nov 2018)
  * Addition to pod format content (Nov 2018)
  * Use Text::ParseWords not naive split (mohawk2)
  * Modernize t/require.t (mohawk2)
* Mon Oct 16 2017 coolo@suse.com
- updated to 1.20
  see /usr/share/doc/packages/perl-ExtUtils-F77/CHANGES
  v1.20 released May 28th 2016
  - -----------------------------
  * Apply upstream FreeBSD patch thanks to srezic for submitting
  * Fix fallback compiler logic to support gcc-5.x and higher
  * Limited Improved gfortran linking on OS X Yosemite+ to OS X
  v1.19_3 released May 28th 2016
  - -----------------------------
  * Apply upstream FreeBSD patch thanks to srezic for submitting
  v1.19_2 released May 28th 2016
  - -----------------------------
  * Fix fallback compiler logic to support gcc-5.x and higher
  v1.19_1 released Mar 6th 2016
  - ---------------------------
  * Limited Improved gfortran linking on OS X Yosemite+ to OS X
  v1.19 released Dec 12th 2015
  - ---------------------------
  * Improved gfortran linking on OS X Yosemite+ which avoids PERL_DL_NONLAZY meltdowns
  v1.18 released Jul 7th 2015
  - --------------------------
  * resolve rt.cpan.org bug #104495: MinGW now needs to link to libquadmath.a
    Thanks for the patch, kmx.
  v1.17_01 released Jul 6th 2014
  - -----------------------------
  * Graham Bell's fix to "Add check for GNU fortran .so files as well as .a."
  * Typo fix by dsteinbrunner
  * Fix Cygwin table to use Generic GNU settings
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Fri Jan  7 2011 vcizek@novell.com
- update to 1.17
  * Derek Lamb's patch to avoid an uninitialised variable error.
  * Diab Jarius's Solaris Studio 10 patch and his gfortran patch (with mods).
  Note g77 is still the default if both it and gfortran are present.
  * Rob's big Win32 patch (Nov 2010 version)
  * ** IMPORTANT. Added in simplification of GNU fortran compilers (g77, gfortran, g95, fort77)
  etc. suggested by Tim Jeness. I used his code but made a slightly different
  implementaion introducing a 'Generic' 'GNU' database entry to which others point.
  This also superceded some of the above patches.
  * Removed places where .gcclibs() is added to the link line, this appears to no loner
  be necessary. Routine left in there (but orphaned) just in case.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Jun 11 2007 anicka@suse.cz
- update to 1.16
  * Added new config entry for Darwin/OSX (using gcc 4.0 and g77,
    gfortran or g95)
  * Added new entry for gfortran under Linux
  * Works fine under g77 on intel Mac OS X.
- remove our gfortran patch, fixed in upstream
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Fri Jan 13 2006 anicka@suse.cz
- update to 1.15
* Mon Apr 18 2005 mjancar@suse.de
- fix for gcc 4.0
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Wed Jun 18 2003 mjancar@suse.cz
- fix filelist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Wed Jan 16 2002 rvasice@suse.cz
- initial package release (version 1.14)
